==> haskell-deferred-folds-0.9.10-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-deferred-folds.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: deferred-folds
version: 0.9.10
id: deferred-folds-0.9.10-HvgKsqDrNv7IAXIRZkrOyE
key: deferred-folds-0.9.10-HvgKsqDrNv7IAXIRZkrOyE
license: MIT
copyright: (c) 2018, Metrix.AI
maintainer: Metrix.AI Tech Team <tech@metrix.ai>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
stability: Experimental
homepage: https://github.com/metrix-ai/deferred-folds
synopsis: Abstractions over deferred folds
description:
    This library is in an experimental state.
    Users should be prepared for frequent updates.
category: Folding
abi: ef918c7998d32bd731b870b1e0bf1a3b
exposed: True
exposed-modules:
    DeferredFolds.Unfoldl DeferredFolds.UnfoldlM DeferredFolds.Unfoldr
hidden-modules: DeferredFolds.Types DeferredFolds.UnfoldrM
                DeferredFolds.Defs.Unfoldl DeferredFolds.Defs.UnfoldlM
                DeferredFolds.Defs.Unfoldr DeferredFolds.Defs.UnfoldrM
                DeferredFolds.Prelude
import-dirs: /usr/lib/ghc-8.6.3/site-local/deferred-folds-0.9.10
library-dirs: /usr/lib/ghc-8.6.3/site-local/deferred-folds-0.9.10
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/deferred-folds-0.9.10
hs-libraries: HSdeferred-folds-0.9.10-HvgKsqDrNv7IAXIRZkrOyE
depends:
    base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    foldl-1.4.5-9mKtAE6uTpbGUIHFT4RFPS
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    primitive-0.6.4.0-1mvPxVOk6Q6KOkWCZxqESf transformers-0.5.5.0
    unordered-containers-0.2.9.0-BISrknrydugK8yp2XIgTJd
    vector-0.12.0.2-5G85DK6NPIx1LphnqJy7eO
haddock-interfaces: /usr/share/doc/haskell-deferred-folds/html/deferred-folds.haddock
haddock-html: /usr/share/doc/haskell-deferred-folds/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-deferred-folds-0.9.10-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-deferred-folds.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: deferred-folds
version: 0.9.10
id: deferred-folds-0.9.10-IMyvjOJ6XCIEv1FsXNtUTx
key: deferred-folds-0.9.10-IMyvjOJ6XCIEv1FsXNtUTx
license: MIT
copyright: (c) 2018, Metrix.AI
maintainer: Metrix.AI Tech Team <tech@metrix.ai>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
stability: Experimental
homepage: https://github.com/metrix-ai/deferred-folds
synopsis: Abstractions over deferred folds
description:
    This library is in an experimental state.
    Users should be prepared for frequent updates.
category: Folding
abi: 31bc657a2107a9a205c10cbc53c8f634
exposed: True
exposed-modules:
    DeferredFolds.Unfoldl DeferredFolds.UnfoldlM DeferredFolds.Unfoldr
hidden-modules: DeferredFolds.Types DeferredFolds.UnfoldrM
                DeferredFolds.Defs.Unfoldl DeferredFolds.Defs.UnfoldlM
                DeferredFolds.Defs.Unfoldr DeferredFolds.Defs.UnfoldrM
                DeferredFolds.Prelude
import-dirs: /usr/lib/ghc-8.6.3/site-local/deferred-folds-0.9.10
library-dirs: /usr/lib/ghc-8.6.3/site-local/deferred-folds-0.9.10
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/deferred-folds-0.9.10
hs-libraries: HSdeferred-folds-0.9.10-IMyvjOJ6XCIEv1FsXNtUTx
depends:
    base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    foldl-1.4.5-6doait6LJF8CY46qP7RqNA
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    primitive-0.6.4.0-1mvPxVOk6Q6KOkWCZxqESf transformers-0.5.5.0
    unordered-containers-0.2.10.0-6u5qZnIDidK2MmAyNc87rJ
    vector-0.12.0.2-5G85DK6NPIx1LphnqJy7eO
haddock-interfaces: /usr/share/doc/haskell-deferred-folds/html/deferred-folds.haddock
haddock-html: /usr/share/doc/haskell-deferred-folds/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
